@@ -145,7 +145,7 @@ class ErrorMsgLogV1():
 
 
 class Lidar3dObj():
-    def __init__(self, frameNum, id, number, category, position=None, rotation=None, dimension=None,
+    def __init__(self, frameNum, id, number, category, position, rotation, dimension,
                  lidar_attr=None, quaternion=None,pointCount=None,vertices=None,type=None):
         self.frameNum = frameNum
         self.id = id
@@ -178,6 +178,30 @@ class Lidar3dObj():
         return _data_dict
 
 
+class Lidar3dPolygonObj():
+    def __init__(self, frameNum, id, number, category,lidar_attr=None,vertices=None,type=None):
+        self.frameNum = frameNum
+        self.id = id
+        self.number = number
+        self.category = category
+        self.lidar_attr = DotDict(lidar_attr) if lidar_attr else DotDict() # 属性
+        self.vertices = vertices
+        self.type = type
+
+    def __repr__(self):
+        return f"{self.id} {self.category} {self.number}"
+
+    def to_dict(self):
+        _data_dict = {
+            "frameNum":self.frameNum,
+            "id":self.id,
+            "number":self.number,
+            "category":self.category,
+            "vertices":self.vertices,
+            "labels":"" if self.lidar_attr else json.dumps(self.lidar_attr,ensure_ascii=False),
+        }
+        return _data_dict
+
 
 class Lidar3dImageRect():
     def __init__(self, frameNum, id, number,type, category, position, dimension,imageNum=None,
